Package: spiky
Type: Package
Title: Spike-in calibration for cell-free MeDIP
Description: spiky implements methods and model generation for cfMeDIP (cell-free methylated DNA immunoprecipitation) with spike-in controls. CfMeDIP is an enrichment protocol which avoids destructive conversion of scarce template, making it ideal as a "liquid biopsy," but creating certain challenges in comparing results across specimens, subjects, and experiments. The use of synthetic spike-in standard oligos allows diagnostics performed with cfMeDIP to quantitatively compare samples across subjects, experiments, and time points in both relative and absolute terms.
Version: 1.19.0
Date: 2023-04-19
Authors@R: c(person("Samantha", "Wilson", role=c("aut")), 
             person("Lauren", "Harmon", role=c("aut")),
             person("Tim", "Triche", role=c("aut","cre"),
                    email="trichelab@gmail.com"))
biocViews: DifferentialMethylation, DNAMethylation, Normalization,
        Preprocessing, QualityControl, Sequencing
URL: https://github.com/trichelab/spiky
BugReports: https://github.com/trichelab/spiky/issues
License: GPL-2
Depends: Rsamtools, GenomicRanges, R (>= 3.6.0)
Imports: stats, scales, bamlss, methods, tools, IRanges, Biostrings,
        GenomicAlignments, BlandAltmanLeh, GenomeInfoDb, BSgenome,
        S4Vectors, graphics, ggplot2, utils
Suggests: covr, testthat, rmarkdown, markdown, knitr, devtools,
        BSgenome.Mmusculus.UCSC.mm10.masked,
        BSgenome.Hsapiens.UCSC.hg38.masked, BiocManager
RoxygenNote: 7.2.1
Roxygen: list(markdown = TRUE)
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
git_url: https://git.bioconductor.org/packages/spiky
git_branch: devel
git_last_commit: 42d312e
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 23:33:27 UTC; biocbuild
Author: Samantha Wilson [aut],
  Lauren Harmon [aut],
  Tim Triche [aut, cre]
Maintainer: Tim Triche <trichelab@gmail.com>
Built: R 4.6.0; ; 2026-05-19 05:10:51 UTC; unix
