# Generated by roxygen2: do not edit by hand

export(add_frag_info)
export(bam_to_bins)
export(bin_pmol)
export(convertPairedGRtoGR)
export(covg_to_df)
export(find_spike_contigs)
export(generate_spike_fasta)
export(get_base_name)
export(get_binned_coverage)
export(get_merged_gr)
export(get_spike_depth)
export(get_spiked_coverage)
export(kmax)
export(kmers)
export(methylation_specificity)
export(model_bam_standards)
export(model_glm_pmol)
export(parse_spike_UMI)
export(predict_pmol)
export(process_spikes)
export(read_bedpe)
export(rename_spike_seqlevels)
export(rename_spikes)
export(scan_genomic_bedpe)
export(scan_genomic_contigs)
export(scan_methylation_specificity)
export(scan_spike_bedpe)
export(scan_spike_contigs)
export(scan_spike_counts)
export(scan_spiked_bam)
export(seqinfo_from_header)
export(spike_bland_altman_plot)
export(spike_counts)
export(tile_bins)
exportMethods(plot)
import(BSgenome)
import(Biostrings)
import(BlandAltmanLeh)
import(GenomeInfoDb)
import(GenomicAlignments)
import(GenomicRanges)
import(IRanges)
import(Rsamtools)
import(S4Vectors)
import(bamlss)
import(ggplot2)
import(methods)
import(scales)
import(tools)
importFrom(graphics,barplot)
importFrom(graphics,par)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(stats,glm)
importFrom(stats,predict)
importFrom(utils,data)
